# Code of Conduct

## Our Pledge

We are committed to making participation in this project a harassment-free experience for everyone.

## Our Standards

- Be respectful and constructive
- Accept feedback gracefully
- Focus on what's best for the community

## Enforcement

Instances of unacceptable behavior may be reported to the project maintainers. All complaints will be reviewed and investigated.

This Code of Conduct is adapted from the [Contributor Covenant](https://www.contributor-covenant.org/), version 2.1.
